const fs = require('fs');
const path = require('path');
const archiver = require('archiver');
const OSS = require('ali-oss');

let argvStr = process.argv.slice(3).join(',');
argvStr = `{"${argvStr.replace(/\,/g, '","').replace(/=/g, '":"')}"}`;
const argvJson = JSON.parse(argvStr);

if (
  !argvJson.accessKeyId ||
  !argvJson.accessKeySecret ||
  !argvJson.distPath ||
  !argvJson.ossUrl ||
  !argvJson.ossUrl.startsWith('hy')
)
  throw new Error('缺少参数:' + argvStr);

// console.log(argvJson);

const OSS_OPTIONS = {
  accessKeyId: argvJson.accessKeyId,
  accessKeySecret: argvJson.accessKeySecret,
  region: 'oss://qtable/',
  bucket: 'qtable',
  endpoint: 'https://oss-cn-beijing.aliyuncs.com',
};

function zipDirectory(originPath, zipDir) {
  const output = fs.createWriteStream(zipDir);
  const archive = archiver('zip');

  archive.pipe(output);

  archive.directory(originPath, false);

  archive.finalize();

  return new Promise((resolve, reject) => {
    archive.on('error', reject);

    archive.on('finish', resolve);
  });
}

function uploadFile(sourceDir, ossDir) {
  const store = new OSS(OSS_OPTIONS);
  // https://gtable.oss-cn-beijing.aliyuncs.com/apps/hy/RELEASESjson
  return store.put(`apps/hy/${ossDir}`, `${sourceDir}`).then(
    (res) => {
      console.log('上传成功:', sourceDir, '=>', res.url);
    },
    (reason) => {
      console.log('上传失败!', reason);
    }
  );
}

const zipname = path.basename(argvJson.ossUrl);
const zipDir = path.join(process.cwd(), zipname);
const sourceDir = path.join(process.cwd(), argvJson.distPath);
zipDirectory(sourceDir, zipDir).then(
  () => {
    console.log('压缩完成');
    return uploadFile(zipDir, argvJson.ossUrl.replace('hy/', ''));
  },
  (err) => {
    console.error('压缩失败', err);
  }
);
